@@ -53,9 +53,27 @@ class Command:
             teleop_mode = 1
             mode = False
         if mode and self.father.status.api.motion_mode != linuxcnc.TRAJ_MODE_FREE or not mode and self.father.status.api.motion_mode != linuxcnc.TRAJ_MODE_TELEOP:
-            self.set_teleop_enable_mode(teleop_mode)
+            self.set_teleop_enable(teleop_mode)
         return mode
 
+    def jog_continuous(self, axis, speed, mode):
+        if mode == "":
+            mode = self.get_jog_mode()
+        self.set_mode(linuxcnc.MODE_MANUAL, 0.5)
+        self.api.jog(linuxcnc.JOG_CONTINUOUS, mode, int(axis), int(speed))
+
+    def jog_increment(self, axis, speed, increment, mode):
+        if mode == "":
+            mode = self.get_jog_mode()
+        increment = float(increment)
+        self.set_mode(linuxcnc.MODE_MANUAL, 0.5)
+        self.api.jog(linuxcnc.JOG_INCREMENT, mode, int(axis), int(speed), increment)
+
+    def jog_stop(self, axis, mode):
+        if mode == "":
+            mode = self.get_jog_mode()
+        self.api.jog(linuxcnc.JOG_STOP, mode, int(axis))
+
     def home_axis(self, axis):
         self.set_mode(linuxcnc.MODE_MANUAL, 1)
         self.api.home(axis)
@@ -65,7 +83,7 @@ class Command:
         homed = True
         self.father.status.api.poll()
         for i, h in enumerate(self.father.status.api.homed):
-            if i >= len(self.father.machine.coordinates):
+            if i >= len(self.father.framework.machine.axis):
                 break
             homed = homed and h
         return homed
